developerscripttools.DirectoryScript
====================================

.. abjad-lineage:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript

.. autoclass:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.DirectoryScript.DirectoryScript.DirectoryScript.__repr__
   :noindex:
